@@ -1,7 +1,11 @@
+# SPDX-FileCopyrightText: 2003 Python Software Foundation
 # SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
 # SPDX-FileCopyrightText: Copyright (c) 2021 Alec Delaney
 #
 # SPDX-License-Identifier: MIT
+# SPDX-License-Identifier: PSF-2.0
+# SPDX-License-Identifier: 0BSD
+
 """
 `circuitpython_csv`
 ================================================================================
@@ -25,7 +29,7 @@ None
 
 """
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 __repo__ = "https://github.com/tekktrik/CircuitPython_CSV.git"
 
 import re
@@ -174,7 +178,7 @@ class DictReader:
 
     def __init__(
         self,
-        f: io.TextIOWrapper,
+        f: io.TextIOWrapper,  # pylint: disable=invalid-name
         fieldnames: Optional[Sequence[str]] = None,
         restkey: Optional[str] = None,
         restval: Optional[Any] = None,
@@ -226,7 +230,7 @@ class DictWriter:
 
     def __init__(
         self,
-        f: io.TextIOWrapper,
+        f: io.TextIOWrapper,  # pylint: disable=invalid-name
         fieldnames: Sequence[str],
         restval: str = "",
         extrasaction: str = "raise",
